"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.extractConsoleLogs = void 0;
const rambdax_1 = require("rambdax");
const LIMIT = 115;
const MARK = 'NIKETA_MARKER';
function mergeLogs(hash) {
    const iterable = (x) => {
        const lineDecoration = [];
        rambdax_1.forEach((xInstance, lineNumber) => {
            const decoration = xInstance.length === 1 ? xInstance[0] : xInstance.join(' ');
            lineDecoration.push({
                decoration,
                line: lineNumber,
            });
        }, x);
        return lineDecoration;
    };
    return rambdax_1.map(iterable, hash);
}
function extractConsoleLogs(input) {
    const withMarker = input.replace(/console\.log/g, `${MARK} console.log`);
    const parts = withMarker.split('console.log');
    const hash = {};
    const extractor = (part) => {
        const partialLines = part
            .split('\n')
            .filter(Boolean)
            .filter(x => !x.includes(MARK))
            .map(rambdax_1.trim);
        if (partialLines.length === 0)
            return;
        const logLines = [];
        let found = false;
        let fileName = '';
        let lineNumber = 0;
        partialLines.forEach(partialLine => {
            if (found)
                return;
            const matched = partialLine.match(/\([a-zA-Z_\-\.\/]+:[0-9]+:[0-9]+\)$/);
            if (matched === null && !found)
                return logLines.push(partialLine);
            if (matched === null)
                return;
            found = true;
            const [fileNameRaw, lineNumberRaw] = matched[0].split(':');
            lineNumber = Number(lineNumberRaw);
            fileName = rambdax_1.remove(['(', ')'])(fileNameRaw);
        });
        if (rambdax_1.anyFalse(found, lineNumber, fileName))
            return;
        if (hash[fileName] === undefined)
            hash[fileName] = {};
        if (hash[fileName][lineNumber] === undefined)
            hash[fileName][lineNumber] = [];
        const decoration = rambdax_1.take(LIMIT)(logLines.join(' '));
        hash[fileName][lineNumber].push(decoration);
    };
    parts.forEach(extractor);
    return mergeLogs(hash);
}
exports.extractConsoleLogs = extractConsoleLogs;
