"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.sortPackageJson = void 0;
const fs_extra_1 = require("fs-extra");
const rambdax_1 = require("rambdax");
const ORDER = [
    'name',
    'scripts',
    'typings',
    'main',
    'version',
    'dependencies',
    'devDependencies',
    'jest',
    'files',
    'repository',
    'license',
    'git',
    'author',
    'depFn',
];
async function sortPackageJson(location, options = { testing: false }) {
    const { testing } = options;
    const unsorted = await fs_extra_1.readJson(location);
    const ignored = rambdax_1.omit(ORDER, unsorted);
    const sorted = {};
    ORDER.forEach(property => {
        if (unsorted[property] === undefined)
            return;
        sorted[property] = unsorted[property];
    });
    const toSave = {
        ...sorted,
        ...ignored,
    };
    const output = testing ?
        rambdax_1.replace('.json', '-sorted.json', location) :
        location;
    await fs_extra_1.outputJson(output, toSave, { spaces: 2 });
}
exports.sortPackageJson = sortPackageJson;
