"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isLintable = exports.isMessageCorrect = exports.defaultEmit = exports.extractNumber = exports.maybeWarn = exports.parse = exports.toNumber = exports.cleanAngularLog = exports.LONG_SEPARATOR = exports.SHORT_SEPARATOR = exports.SUCCESS_ICON = exports.ERROR_ICON = exports.JEST_BIN = void 0;
const helpers_fn_1 = require("helpers-fn");
const rambdax_1 = require("rambdax");
exports.JEST_BIN = './node_modules/jest/bin/jest.js';
exports.ERROR_ICON = '❌';
exports.SUCCESS_ICON = '🐬';
exports.SHORT_SEPARATOR = rambdax_1.repeat('🍄', 2).join('');
exports.LONG_SEPARATOR = rambdax_1.repeat('🍺', 20).join('');
function cleanAngularLog(x) {
    return {
        ...x,
        stderr: rambdax_1.remove(/ts-jest\[.+/, x.stderr),
    };
}
exports.cleanAngularLog = cleanAngularLog;
function toNumber(x) {
    return x === undefined || Number.isNaN(Number(x)) ? 0 : Number(x);
}
exports.toNumber = toNumber;
function parse(x) {
    const result = Math.round(x * 100) / 100;
    return parseFloat(`${result}`);
}
exports.parse = parse;
const maybeWarn = (x) => (x < 0 ? `❗${x}` : x);
exports.maybeWarn = maybeWarn;
function extractNumber(text) {
    const justText = text.replace(/[\u001b\u009b][[()#;?]*(?:[0-9]{1,4}(?:;[0-9]{0,4})*)?[0-9A-ORZcf-nqry=><]/g, '');
    const asNumber = Number(justText.trim());
    if (rambdax_1.type(asNumber) === 'NaN') {
        return justText.trim();
    }
    return asNumber;
}
exports.extractNumber = extractNumber;
const defaultEmit = (x) => console.log(x, 'emit not yet initialized');
exports.defaultEmit = defaultEmit;
const messageSchema = {
    hasTypescript: Boolean,
    fileName: String,
};
function isMessageCorrect(message) {
    const isCorrect = rambdax_1.pass(message)(messageSchema);
    if (!isCorrect) {
        helpers_fn_1.log('isMessageCorrect', 'error');
        helpers_fn_1.log(message, 'obj');
        return false;
    }
    return true;
}
exports.isMessageCorrect = isMessageCorrect;
function isLintable(fileName) {
    return fileName.endsWith('.js') || fileName.endsWith('.ts');
}
exports.isLintable = isLintable;
